@@ -7,7 +7,7 @@ use SQL::Abstract;
 use base qw( Authen::Htpasswd );
 __PACKAGE__->mk_accessors($_) for qw( dbh table sql );
 
-our $VERSION = '0.00002';
+our $VERSION = '0.00003';
 
 sub new {
     my $class = shift;
@@ -106,6 +106,9 @@ Authen::Htpasswd::Trac - interface to read and modify Trac password files
   my $auth = Authen::Htpasswd::Trac->new( '/path/to/.htpasswd', { trac => '/path/to/trac.db'} );
   my @rs   = $auth->check_user_permissions($username, $password);
 
+  $auth->add_permission('myuser', 'TRAC_ADMIN');
+  $auth->remove_permission('myuser', 'TRAC_ADMIN');
+
 =head1 DESCRIPTION
 
 This module based on Authen::Htpasswd.
@@ -115,13 +118,21 @@ And interface to trac with account-manager plugin.
 
 =head2 new( password file, { trac => 'database file of trac' })
 
-=head2 find_user_permissions( username, password );
+=head2 find_user_permissions( username, password )
 
-  This method returns trac permission names.
+  Returns trac permission names.
+
+=head2 add_permission( username, action )
+
+  Add permission to trac.
+
+=head2 remove_permission
+
+  Remove permission to trac.
 
 =head2 other methods
 
-  perldoc Authen::Htpasswd
+  $ perldoc Authen::Htpasswd
 
 =head1 AUTHOR
 
